@@ -173,7 +173,7 @@ int tchan::operator>=(tchan &chan) {
   return(strcasecmp(name,chan.name)>=0);
 }
 
-tchan::tchan(char *something) {
+tchan::tchan(const char *something) {
   int n;
   ison=0;
   numops=0;
