@@ -20,7 +20,7 @@ class tchan {
     char *topic;
     int operator==(tchan &chan);
     int operator>=(tchan &chan);
-    tchan(char *);
+    tchan(const char *);
     tchan();
     int addnicks(char *);
     int addnick(char *);
