@@ -290,7 +290,7 @@ tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport) {
   }
 }
 
-tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport, char *thefile, int thesize, int dccflags, char *renamedfile) {
+tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport, char *thefile, int thesize, int dccflags, const char *renamedfile) {
   // DCC SEND ACCEPT
   twindow window;
   struct sockaddr_in addr;
@@ -400,7 +400,7 @@ tdcc::tdcc(tserver *serverp, const char *thenick, char *theip, int theport, char
   memset(buffer,0,BUFLEN);
 }
 
-tdcc::tdcc(tserver *serverp, char *thenick) {
+tdcc::tdcc(tserver *serverp, const char *thenick) {
   // DCC CHAT SEND
   char temp[TEMPLEN];
   twindow window;
@@ -541,7 +541,7 @@ tdcc::tdcc(tserver *serverp, char *thenick) {
   chatnum++;
 }
   
-tdcc::tdcc(tserver *serverp, char *thenick, char *thefile) {
+tdcc::tdcc(tserver *serverp, const char *thenick, const char *thefile) {
   // DCC SEND SEND
   char temp[TEMPLEN];
   twindow window;
@@ -693,7 +693,7 @@ tdcc::tdcc(tserver *serverp, char *thenick, char *thefile) {
   }
 }
   
-int tdcc::senddata(char *message) {
+int tdcc::senddata(const char *message) {
   char *temp=strmem(message,1);
   if(connected) {
     strcat(temp,"\n");
