@@ -30,7 +30,8 @@ static char bufhigh[20];
 static char *buflowp;
 static char *bufhighp;
 
-int append(char *low, char *high, string &assemble, int argc, char **argv) {
+int append(char *low, char *high, string &assemble, int argc,
+	   const char * const * argv) {
   int start=atoi(low);
   int end=atoi(high);
   int n;
@@ -56,7 +57,8 @@ int append(char *low, char *high, string &assemble, int argc, char **argv) {
   return 0;
 }
 
-char *fparsev(char *type, int server, int argc, char **argv) {
+char *fparsev(const char *type, int server, int argc,
+	      const char * const * argv) {
   // %X- %-X %X-Y %- %%
   // Replaces arguments with an escaped version of a space seperated arg list.
   // Argument is then evaluated within a set.
@@ -208,11 +210,12 @@ char *fparse(char *type, int server, int arguments, ...) {
   return(fparsev(type, server, arguments, args));
 }
 
-char *fgetformat(char *type) {
+char *fgetformat(const char *type) {
   return hash_get(&formats,type);
 }
 
-char *fgetpathnames(char *type, int server, int argc, char **argv) {
+char *fgetpathnames(const char *type, int server, int argc,
+		    const char * const * argv) {
   char *location;
   char *newloc;
   twindow window;
@@ -351,7 +354,8 @@ char *fgetpathnames(char *type, int server, int argc, char **argv) {
   return newloc;
 }
 
-void fdisplayv(char *type, int server, int argc, char **argv) {
+void fdisplayv(const char *type, int server, int argc,
+	       const char * const * argv) {
   char *result;
   char *newloc;
 
@@ -367,7 +371,7 @@ void fdisplayv(char *type, int server, int argc, char **argv) {
     return;
   }
 
-  if(Tcl_SplitList(TT_Interp,newloc,&listc,&listv)==TCL_ERROR) {
+  if(Tcl_SplitList(TT_Interp,newloc,&listc,(const char ***)&listv)==TCL_ERROR) {
     free(newloc);
     TT_Eval(TT_ARGS,"error {fdisplay:  Given pathname argument is not a proper TCL list.}");
     return;
@@ -400,6 +404,6 @@ void fdisplay(char *type, int server, int arguments, ...) {
   fdisplayv(type, server, arguments, args);
 }
 
-int fexists(char *type) {
+int fexists(const char *type) {
   return (int)hash_get(&formats,type);
 }
