@@ -23,7 +23,7 @@ void hash_destroy(hash *table) {
   Tcl_DeleteHashTable(table);
 }
 
-int hash_set(hash *table, char *key, char *value) {
+int hash_set(hash *table, const char *key, const char *value) {
   Tcl_HashEntry *entry;
   char *data;
   int newentry;
@@ -37,7 +37,7 @@ int hash_set(hash *table, char *key, char *value) {
   }
 }
 
-char *hash_get(hash *table, char *key) {
+char *hash_get(hash *table, const char *key) {
   Tcl_HashEntry *entry;
   if(!(entry=Tcl_FindHashEntry(table,key))) {
     return 0;
