@@ -128,7 +128,7 @@ class tnick {
       global = tn.global;
     }
 
-    tnick(char *nick) {
+    tnick(const char *nick) {
       entry = strdup(nick);
       if(entry[0]=='@') {
         oped=1;
