@@ -38,7 +38,7 @@ class tquery {
       time = q.time;
     }
 
-    tquery(char *something) {
+    tquery(const char *something) {
       name = mystrdup(something);
       pathname[0]=0;
     }
