@@ -11,7 +11,6 @@
 #include <ctype.h>
 #include <netdb.h> 
 #include <stdarg.h>
-#include <iostream.h>
 
 #include "config.h"
 
@@ -178,7 +177,6 @@ void tserver::ial_prefix(char *prefix) {
 }
 
 void tserver::ial_add(char *nick, char *userhost) {
-  int n;
   char *tempnick = mystrdup(nick);
   lc(tempnick);
 
@@ -209,7 +207,7 @@ tserver::~tserver() {
   Tcl_DeleteFileHandler(sockfd);
 }
 
-void tserver::createchannel(char *channelname) {
+void tserver::createchannel(const char *channelname) {
   twindow window;
   int n;
   tchan chan(channelname);
@@ -232,7 +230,7 @@ void tserver::createchannel(char *channelname) {
   }
 }
 
-void tserver::createquery(char *queryname) {
+void tserver::createquery(const char *queryname) {
   twindow window;
   int n;
   tquery query(queryname);
@@ -253,7 +251,7 @@ void tserver::createquery(char *queryname) {
   }
 }
 
-tserver::tserver(char *address, int theport, char *password) {
+tserver::tserver(const char *address, int theport, const char *password) {
   twindow window;
   int n;
 
@@ -312,7 +310,7 @@ tserver::tserver(char *address, int theport, char *password) {
   TT_EvalF(TT_ARGS,"totop %d",n);
 }
 
-void tserver::server(char *address, int theport, char *password) {
+void tserver::server(const char *address, int theport, const char *password) {
   twindow window;
   twindow *windowp;
 
@@ -1145,7 +1143,7 @@ void tserver::handle_connect(void) {
   }
 }
 
-int tserver::senddata(char *message) {
+int tserver::senddata(const char *message) {
   char temp[IRCMAXLEN];
   if(strlen(message)>=(IRCMAXLEN-2)) {
     echo(" \0030,5 ERROR \003 Message too long, please shorten and resend.",currentwindow,1);
