@@ -121,10 +121,13 @@ class tdcc : public handleable {
     long long timestarted;
     long dccseconds;
     long dccmilliseconds;
-    tdcc(class tserver *serverp, char *thenick);
-    tdcc(class tserver *serverp, char *thenick, char *thefile);
+    tdcc(class tserver *serverp, const char *thenick);
+    tdcc(class tserver *serverp,
+	 const char *thenick,
+	 const char *thefile);
     tdcc(class tserver *serverp, const char *thenick, char *theip, int theport);
-    tdcc(class tserver *serverp, const char *thenick, char *theip, int theport, char *thefile, int thesize, int dccflags, char *renamedfile);
+    tdcc(class tserver *serverp, const char *thenick, char *theip, int theport,
+	 char *thefile, int thesize, int dccflags, const char *renamedfile);
     int operator>=(tdcc &dcc) {
       if(strlen(dcc.nick)) return 0; else return 0;
     }
@@ -149,7 +152,7 @@ class tdcc : public handleable {
     void usedata();
     void handle_outgoing();
     void complete_connect(void);
-    int senddata(char *);
+    int senddata(const char *);
     int disconnect(void);
     void do_accept(void);
     void perror(char *message);
@@ -259,10 +262,10 @@ class tserver : public handleable {
     void ial_add(char *, char *);
     void perror(char *);
     void perror(char *message, int number);
-    void createchannel(char *);
-    void createquery(char *);
-    tserver(char *address, int theport, char *password);
-    void server(char *address, int theport, char *password);
+    void createchannel(const char *);
+    void createquery(const char *);
+    tserver(const char *address, int theport, const char *password);
+    void server(const char *address, int theport, const char *password);
     ~tserver();
     void usedata();
 
@@ -275,7 +278,7 @@ class tserver : public handleable {
     int getsockfd();
 
     // Network Functions
-    int senddata(char *);
+    int senddata(const char *);
     int do_connect(void);
     int disconnect(int);
 
