@@ -217,7 +217,7 @@ int TT_Proc___template__channels(TT_PROC_ARGS) {
 	if(assemble.length()) assemble+=" ";
 	assemble+=channelp->name;
       }
-      Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
+      Tcl_SetResult(interp,(char *)TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
     }
   }
   return TCL_OK;
@@ -419,7 +419,7 @@ int TT_Proc___template__index(TT_PROC_ARGS) {
     Tcl_SetResult(interp,"Usage: index",TCL_VOLATILE);
     return TCL_ERROR;
   }
-  Tcl_SetResult(interp,argv[1],TCL_VOLATILE);
+  Tcl_SetResult(interp,(char *)argv[1],TCL_VOLATILE);
   return TCL_OK;
 }
 
@@ -545,7 +545,7 @@ int TT_Proc___template__modenicks(TT_PROC_ARGS) {
 	  if(assemble.length()) assemble+=" ";
 	  assemble+=nickp->getentry();
 	}
-	Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
+	Tcl_SetResult(interp,(char *)TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
       }
     }
   }
@@ -634,7 +634,7 @@ int TT_Proc___template__nicks(TT_PROC_ARGS) {
 	  if(assemble.length()) assemble+=" ";
 	  assemble+=nickp->getname();
 	}
-	Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
+	Tcl_SetResult(interp,(char *)TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
       }
     }
   }
@@ -850,7 +850,7 @@ int TT_Proc___template__queries(TT_PROC_ARGS) {
 	if(assemble.length()) assemble+=" ";
 	assemble+=queryp->getname();
       }
-      Tcl_SetResult(interp,TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
+      Tcl_SetResult(interp,(char *)TT_StrF(TT_ARGS,"split %q \" \"",assemble.c_str()),TCL_VOLATILE);
     }
   }
   return TCL_OK;
@@ -878,7 +878,7 @@ int TT_Proc___template__script(TT_PROC_ARGS) {
   char temp[TEMPLEN];
   char assemble[TEMPLEN];
   char *pos;
-  char *afterslash;
+  const char *afterslash;
   int n;
   if(argc>=3) {
     sprintf(window.pathname,".status%s",argv[1]);
@@ -998,7 +998,7 @@ int TT_Proc___template__unscript(TT_PROC_ARGS) {
   char temp[TEMPLEN];
   char storage[TEMPLEN];
   char *pos;
-  char *afterslash;
+  const char *afterslash;
   int n;
   if(argc>=3) {
     sprintf(window.pathname,".status%s",argv[1]);
@@ -1032,16 +1032,19 @@ int TT_Proc___template__userhost(TT_PROC_ARGS) {
   twindow window;
   twindow *windowp;
   char *userhost;
+  char *temp;
   int n;
   if(argc>=3) {
     sprintf(window.pathname,".status%s",argv[1]);
     if((windowp=windows.find(window))) {
       if(windowp->server) {
-	for(n=0;n<(signed)strlen(argv[2]);n++) argv[2][n]=tolower(argv[2][n]);
+	temp = mystrdup(argv[2]);
+	for(n=0;n<(signed)strlen(temp);n++) temp[n]=tolower(temp[n]);
 	//Tcl_SetResult(interp,(char *)windowp->server->ial[argv[2]].c_str(),TCL_VOLATILE);
-	if((userhost=hash_get(&windowp->server->ial,argv[2]))) {
+	if((userhost=hash_get(&windowp->server->ial,temp))) {
 	  Tcl_SetResult(interp,userhost,TCL_VOLATILE);
 	}
+	free(temp);
       }
     }
   }
