@@ -50,7 +50,7 @@ char *strnum(int num) {
   return thenum;
 }
 
-char *strmem(char *orig, int increment) {
+char *strmem(const char *orig, int increment) {
   void *temp;
   if(orig) {
     if(!(temp=(char *)malloc(strlen(orig)+increment+1))) {
@@ -68,7 +68,7 @@ char *strmem(char *orig, int increment) {
   return (char *)temp;
 }
 
-extern int ischannel(char *string) {
+extern int ischannel(const char *string) {
   if((string[0]=='#')||(string[0]=='&')||(string[0]=='+')) return 1;
   return 0;
 }
