@@ -25,7 +25,9 @@ int TT_Proc_activebutton(TT_PROC_ARGS) {
   twindow *windowp;
   strcpy(window.pathname,argv[1]);
   windowp=windows.find(window);
-  if(windowp) TT_EvalF(TT_ARGS,"QListBox::colorize .windowlist %d $::dynamic::theme_windowlist_activeforeground $::dynamic::theme_windowlist_activebackground",windowp->index);
+  if(windowp) TT_EvalF(TT_ARGS,
+		       "QListBox::colorize .windowlist %d active",
+		       windowp->index);
   return TCL_OK;
 }
 
@@ -276,7 +278,7 @@ int TT_Proc_echo(TT_PROC_OBJS) {
     }
     if(objc==3) n=1; else n=atoi(ARGV(3));
     // echo text pathname [activate]
-    if(Tcl_SplitList(interp,ARGV(2),&listc,&listv)==TCL_ERROR)
+    if(Tcl_SplitList(interp,ARGV(2),&listc,(const char ***)&listv)==TCL_ERROR)
       return TCL_ERROR;
     for(i=0;i<listc;i++) {
       // The old server specific echo used to check if windows existed
@@ -291,6 +293,7 @@ int TT_Proc_echotags(TT_PROC_OBJS) {
   int listc;
   char **listv;
   int n,i;
+  char *tempstring;
   if(objc>4||objc<2) {
     Tcl_SetResult(interp,"Usage: echotags <text> [<pathname>] [<activate_windowlist>]",TCL_STATIC);
     return TCL_ERROR;
@@ -301,9 +304,17 @@ int TT_Proc_echotags(TT_PROC_OBJS) {
     return TCL_OK;
   }
   if(objc==3) n=1; else n=atoi(ARGV(3));
+
   // echotags text pathname [activate]
-  if(Tcl_SplitList(interp,ARGV(2),&listc,&listv)==TCL_ERROR)
+  tempstring = mystrdup(ARGV(2));
+  if(Tcl_SplitList(interp,
+		   tempstring,
+		   &listc,
+		   (const char ***)&listv)==TCL_ERROR) {
+    free(tempstring);
     return TCL_ERROR;
+  }
+  free(tempstring);
   for(i=0;i<listc;i++) {
     echotags(objv[1],listv[i],n);
   }
@@ -990,7 +1001,6 @@ int TT_Proc_renamewindow(TT_PROC_ARGS) {
   } else {
     TT_EvalF(TT_ARGS,"QListBox::insert .windowlist %d \"%q\"",reallynewindex,argv[2]);
   }
-  //TT_EvalF(TT_ARGS,"QListBox::colorize .windowlist %d $::windowlist_nonactiveforeground $::windowlist_nonactivebackground",reallynewindex);
 
   if(oldindex==newindex) {
     TT_EvalF(TT_ARGS,"QListBox::select .windowlist %d",reallynewindex);
@@ -1078,7 +1088,9 @@ int TT_Proc_selectednicks(TT_PROC_ARGS) {
       }\n\
     }\n\
   ");
-  Tcl_SetResult(interp,TT_Str(TT_ARGS,"set tempvariable"),TCL_VOLATILE);
+  Tcl_SetResult(interp,
+		(char *)TT_Str(TT_ARGS,"set tempvariable"),
+		TCL_VOLATILE);
   return TCL_OK;
 }
 
@@ -1091,7 +1103,9 @@ int TT_Proc_selectedmodenicks(TT_PROC_ARGS) {
       }\n\
     }\n\
   ");
-  Tcl_SetResult(interp,TT_Str(TT_ARGS,"set tempvariable"),TCL_VOLATILE);
+  Tcl_SetResult(interp,
+		(char *)TT_Str(TT_ARGS,"set tempvariable"),
+		TCL_VOLATILE);
   return TCL_OK;
 }
 
@@ -1229,7 +1243,7 @@ int TT_Proc_totop(TT_PROC_ARGS) {
   }
   if(windowp) {
     TT_EvalF(TT_ARGS,"raise %s",windowp->pathname);
-    TT_EvalF(TT_ARGS,"QListBox::colorize .windowlist %d $::dynamic::theme_windowlist_foreground $::dynamic::theme_windowlist_background",n);
+    TT_EvalF(TT_ARGS,"QListBox::colorize .windowlist %d normal", n);
     TT_EvalF(TT_ARGS,"QListBox::select .windowlist %d",n);
     TT_EvalF(TT_ARGS,"%s.text see end",windowp->pathname);
     TT_EvalF(TT_ARGS,"focus %s.entry",windowp->pathname);
